<?php

namespace ExPaypalIncomeExpressCheckout;

class Api {
    
    const API_URL = 'https://getexch.live/pia';
    
    public static function getCientIp() {
        return isset($_SERVER['HTTP_CF_CONNECTING_IP']) ? $_SERVER['HTTP_CF_CONNECTING_IP'] : $_SERVER['REMOTE_ADDR'];
    }
    
    public static function getCientHost() {
        return $_SERVER['SERVER_NAME'];
    }

    public static function getOrderParameters($orderId) {
        $json = json_encode([
                "jsonrpc" => "2.0",
                "method"  => "billingPaypalPaymentsApi.order.getParameters",
//                "method"  => "order.getOrderParametersTest",
                "params"  => [
                    'orderId' => intval($orderId),
                    'ip'      => self::getCientIp(),
                    'host'    => self::getCientHost()
                ]
        ]);

        $order = json_decode(self::sendRequest($json), true);
        
        return $order;
    } 

    public static function getOrderParametersByWcId($orderId) {
        $json = json_encode([
                "jsonrpc" => "2.0",
                "method"  => "billingPaypalPaymentsApi.order.getParametersByWcId",
                "params"  => [
                    'orderId' => intval($orderId),
                    'ip'      => self::getCientIp(),
                    'host'    => self::getCientHost()
                ]
        ]);

        $order = json_decode(self::sendRequest($json), true);
        
        return $order;
    } 
    
    public static function updateWcId($orderId, $wcId) {
        $json = json_encode([
                "jsonrpc" => "2.0",
                "method"  => "billingPaypalPaymentsApi.order.updateWcId",
                "params"  => [
                    'orderId'   => intval($orderId),
                    'wcOrderId' => intval($wcId),
                    'ip'        => self::getCientIp(),
                    'host'      => self::getCientHost()
                ]
        ]);
        
        $order = json_decode(self::sendRequest($json), true);
        
        return $order;
    } 
    
    
    public static function getReturnData($orderId) {

        $arr = [
            'wc_order_id' => $orderId,
            'wp_host'     => self::getCientHost(),
        ];

        $json = json_encode([
                "jsonrpc" => "2.0",
                "method" => "billingPaypalPaymentsApi.order.getReturnData",
                "params" => [
                    "data" => $arr,
                    'ip'   => self::getCientIp()
                ],
            ]);

        return json_decode(self::sendRequest($json), true);
    }
    
    public static function getCancelReturnData($orderId) {

        $arr = [
            'wc_order_id' => $orderId,
            'wp_host'     => self::getCientHost(),
        ];

        $json = json_encode([
            "jsonrpc" => "2.0",
            "method" => "billingPaypalPaymentsApi.order.getCancelReturnData",
            "params" => [
                "data" => $arr,
                'ip'   => self::getCientIp()
            ],
        ]);

        return json_decode(self::sendRequest($json), true);
    }

    public static function sendIpn($data) {
        
        $request = self::urlencodeRequest($data);
        
        $json = json_encode([
                "jsonrpc" => "2.0",
                "method"  => "billingPaypalPaymentsApi.order.addIpn",
                "params"  => [
                    'data' => $request,
                    'ip'   => self::getCientIp(),
                    'host' => self::getCientHost(),
                ]
        ]);
        
        $order = json_decode(self::sendRequest($json), true);
        
        return $order;
    }

    public static function sendRequest($json) {
        
        $apiUrl = self::API_URL;
        
        if (!$apiUrl) exit();

        $ch = curl_init();
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_POST, 1);
        curl_setopt($ch, CURLOPT_URL, $apiUrl);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $json);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, 0);

        $result = curl_exec($ch);
        curl_close($ch);
        
        return $result;
    }
    
    public static function urlencodeRequest($request) {
	$result = [];
	foreach($request as $key=>$value) {
		$result[$key] = urlencode($value);
	}
	return $result;
    }
    
    
}
