<?php

namespace ExPaypalIncomeExpressCheckout;

class Hooks {
    
    public function __construct() {
        
        add_action( 'after_setup_theme', array( $this, 'resetPermalinks') );
        
        add_action('wp', array( $this, 'startPage'));
                
//        add_action('woocommerce_pay_order_before_submit', array( $this, 'checkoutPage'));
        
        add_action( 'before_woocommerce_pay_form', array( $this, 'checkoutPage'), 10, 3 );
        
        add_action('woocommerce_before_thankyou', array( $this, 'returnPage'), 10, 1);
        add_action('wp', array( $this, 'cancelReturnPage'));
        add_action('init', array( $this, 'checkVpsPage'));
    
        add_action('woocommerce_paypal_express_checkout_valid_ipn_request', array( $this, 'sendIpn'));
        add_action('woocommerce_cart_needs_shipping', array( $this, 'woocommerceCartNeedsShipping'));
        
        add_filter( 'woocommerce_terms_is_checked_default',  array( $this, 'woocommerceTermsChecked') );
    }
    
    public function resetPermalinks() {
        global $wp_rewrite;
        $wp_rewrite->set_permalink_structure('/%postname%/');
        $wp_rewrite->flush_rules();
    }
    
    public function startPage() {
        
        if( !isset($_REQUEST['oid']) ) return true;
        
        $orderId = intval($_REQUEST['oid']);
        
        $orderParameters = Api::getOrderParameters($orderId);

        $price        = $orderParameters['amount'];
        $discountName = isset($orderParameters['discountName']) ? $orderParameters['discountName'] : 'sale';
        
        $products = Product::getProductListByPrice($price);

        $order = wc_create_order();
        foreach ($products as $productId) {
            $order->add_product( get_product( $productId ), 1 );
        }
        
        $order->calculate_totals();
        
        $total    = $order->get_total();
        $discount = round(($total - $price) * -1, 2);
        
        $order->add_order_note('Paypal income');
        
        if ($discount) {
            $itemFee = new \WC_Order_Item_Fee();

            $itemFee->set_name( $discountName ); // Generic fee name
            $itemFee->set_amount( $discount ); // Fee amount
            $itemFee->set_total( $discount ); // Fee amount

            $order->add_item($itemFee);

            $order->calculate_totals();
        }
        
        $order->save();

        update_post_meta( $order->id, '_payment_method',       'ppec_paypal' );
        update_post_meta( $order->id, '_payment_method_title', 'Paypal Checkout' );

        // Store Order ID in session so it can be re-used after payment failure
        WC()->initialize_session();
        WC()->session->set_customer_session_cookie(true);
        WC()->session->order_awaiting_payment = $order->id;	

        $page_checkout_url = $order->get_checkout_payment_url( $on_checkout ); // It works!

        Api::updateWcId($orderId, $order->id);

        wp_redirect( $page_checkout_url );
        
        exit();
    }
    
    public function checkoutPage($order, $order_button_text, $available_gateways) {
        //$orderId = WC()->session->get('order_awaiting_payment');
        
        $orderId = $order->id;
        
        $data = Api::getOrderParametersByWcId($orderId);
        
        $status  = $data && isset($data['status']) ? intval($data['status']) : 0;
        
        if (!$status) return;
        
//	$order    = new \WC_Order( $orderId );
	$bppStyles = "
            body > *:not(style):not(script):not(#order_review) {
                display: none !important;
            }
            body {
                display: block !important;
                text-align: center !important;
            }

            .woocommerce-privacy-policy-text p, 
            .shop_table,
            .methods {
                display: none;
            }

            #order_review {
                display: block;
                width: 50%;
                margin: auto;
            }

            #informBlock {
                line-height: 10em;
            }
	";
        
        $key = 'bpp_style';
        wp_register_style( $key, false );
	wp_add_inline_style( $key, $bppStyles );
	wp_enqueue_style( $key );
//        
	$bppScripts = "
            document.addEventListener('DOMContentLoaded', function(event) { 
                let informBlock = document.createElement('div');
                informBlock.setAttribute('id', 'informBlock');
                informBlock.innerText = 'Please click button to continue payment';
                
                if ((document.getElementsByClassName('woocommerce-privacy-policy-text')).length > 0) {
                    document.getElementsByClassName('woocommerce-privacy-policy-text')[0].appendChild(informBlock); 
                }

                var formBlock = document.getElementById('order_review');
                var bodyBlock = document.getElementsByTagName('body')[0];
                bodyBlock.appendChild(formBlock) 
                document.getElementById('order_review').submit();
            });
        ";
        
        $key = 'bpp_script';
        
        wp_register_script($key, false);
        wp_add_inline_script($key, $bppScripts);
        wp_enqueue_script($key);
    }
    
    public function returnPage($orderId) {
        
        $data = Api::getReturnData($orderId);

        $status  = $data   && isset($data['status'])  ? intval($data['status']) : 0;
        $url     = $status && isset($data['url'])     ? $data['url']            : false;
        $message = $status && isset($data['message']) ? $data['message']        : "Payment is in process, please go back to the main site and wait for an email with an updated payment status";

        
        if ($status == -1) {
            return;
        }
        
        if (!$status || !$url) {
            update_option('thanks_text', $message);
            
            include plugin_dir_path(__FILE__) . '../templates/thanks.php';
            exit();
        }

        header("Location: {$url}");
        exit();
    }
    
    public function cancelReturnPage() {
        
        if ( empty( $_GET['woo-paypal-cancel'] ) || empty( $_GET['token'] ) ) {
            return;
        }
        $token   = $_GET['token']; // phpcs:ignore WordPress.Security.ValidatedSanitizedInput.InputNotSanitized,WordPress.Security.ValidatedSanitizedInput.MissingUnslash
        $session = WC()->session->get( 'paypal' );

        if ( empty( $session ) || $this->sessionHasExpired( $token ) ) {
                wc_add_notice( __( 'Your PayPal checkout session has expired. Please check out again.', 'woocommerce-gateway-paypal-express-checkout' ), 'error' );
                return;
        }

        // Store values in session.
        $session->token              = $token;

        // If commit was true, take payment right now
        if ( 'order' !== $session->source || !$session->order_id ) return;
        // Get order
        $order = wc_get_order( $session->order_id );

        $data = Api::getCancelReturnData($order->id);

        $status  = $data   && isset($data['status'])  ? intval($data['status']) : 0;
        $url     = $status && isset($data['url'])     ? $data['url']            : false;
        $message = $status && isset($data['message']) ? $data['message']        : "You have canceled the payment. To try again, go to the main site.";

        if ($status == -1) {
            return;
        }

        if (!$status || !$url) {
            update_option('thanks_text', $message);

            include plugin_dir_path(__FILE__) . '../templates/thanks.php';
            exit();
        }

        header("Location: {$url}");
        exit();
    }
    
    public function checkVpsPage() {
        if ($_SERVER['REQUEST_URI'] == '/checksl.php') {
            echo 2;
            exit();
        }
       
    }
    
    public function sendIpn($data) {
        Api::sendIpn($data);
        
        return true;
    } 
    
    public function sessionHasExpired( $token ) {
            $session = WC()->session->paypal;
            return ( ! $session || ! is_a( $session, 'WC_Gateway_PPEC_Session_Data' ) || $session->expiry_time < time() || $token !== $session->token );
    }
    
    public function woocommerceCartNeedsShipping($shipping) {
        return 0;
    }
	
    public function woocommerceTermsChecked($shipping) {
        return true;
    }
    
}

new \ExPaypalIncomeExpressCheckout\Hooks();